==> Mudlib-CD.00.28.tar.gz: lib/sys/macros.h <==
/*
  macros.h

  Useful macros

*/

#ifndef MACROS_DEF
#define MACROS_DEF

#include <language.h>
#include <const.h>
#include "/secure/config.h"

#define MAX(a,b) ((a) > (b) ? (a) : (b))
#define MIN(a,b) ((a) < (b) ? (a) : (b))
#define ABS(a)   ((a) >  0  ? (a) : -(a))

#define MAXINT 2147483647

#define MASTER_OB(ob) (explode(file_name(ob) + "#", "#")[0])
#define OB_NUM(ob) (explode(file_name(ob) + "#", "#")[1])
#define MASTER MASTER_OB(this_object())
#define IS_CLONE (file_name(this_object()) != MASTER)
#define CLONE_COPY clone_object(MASTER)
#define CALL_BY_CLONE (MASTER == MASTER_OB(previous_object()))

#define CALL_BY(file) (MASTER_OB(previous_object()) == file)

#define LOAD_ERR(file)  (catch(call_other(file, "??")))

#define FCHAR(str) extract(str, 0, 0)

#define LCALL this_object()->

#define MYLEV (this_interactive()->query_wiz_level())
#define MYNAME (this_interactive()->query_real_name())
#define MYDOMAIN (this_interactive()->query_domain())

#define METNAME (this_player()->query_name())
#define NONMETNAME (capitalize(this_player()->query_nonmet_name()))
#define ART_NONMETNAME (capitalize((string) LANG_ADDART(this_player()->query_nonmet_name())))

#define TART_NONMETNAME ("The " + this_player()->query_nonmet_name())

#define VBFC(x) ("@@" + x + "@@")

#define VBFC_ME(x) "@@" + x + ":" + file_name(this_object()) + "@@"

/*
 * Here are some useful macros for using when figuring out player names.
 */
#ifdef MET_ACTIVE
#define QMET(func, ob) "@@" + func + ":" + file_name(ob) + "@@"
#else
#define QMET(func, ob) (call_other(ob, func, ob))
#endif
#define QSHORT(ob) QMET("vbfc_short", ob)

 /*
  * QNAME is uses 'value by function call'. It returns either the name
  * of the player or the race preceded by a or an. ob is the object
  * who we want check if we know.
  */
#define QNAME(ob) QMET("query_art_name", ob)

 /*
  * QCNAME is the same as QNAME except that it returns a capital A or An
  */
#define QCNAME(ob) QMET("query_Art_name", ob)
 /*
  * QTNAME is the same as QNAME except that it returns 'the'
  */
#define QTNAME(ob) QMET("query_the_name", ob)
 /*
  * QCTNAME is the same as QTNAME except that it returns a capital 'The'
  */
#define QCTNAME(ob) QMET("query_The_name", ob)
 /*
  * NAME always prints the name of the player with a capital letter.
  */
#define NAME this_player()->query_name()
/*
 * Can ob1 see ob2?
 */
#define CAN_SEE(ob1, ob2)	(ob2->check_seen(ob1))
/*
 * Can ob1 see anything in his/hers environment or is it too dark?
 */
#define CAN_SEE_IN_ROOM(ob)	(environment(ob) && \
				(environment(ob)->query_prop(OBJ_I_LIGHT) > \
				-(ob->query_prop(LIVE_I_SEE_DARK))))

#endif

==> Mudlib-CD.00.30.tar.gz: lib/sys/macros.h <==
/*
  macros.h

  Useful macros

*/

#ifndef MACROS_DEF
#define MACROS_DEF

#include <language.h>
#include <const.h>
#include "/secure/config.h"

#define MAX(a,b) ((a) > (b) ? (a) : (b))
#define MIN(a,b) ((a) < (b) ? (a) : (b))
#define ABS(a)   ((a) >  0  ? (a) : -(a))

#define MAXINT 2147483647

#define MASTER_OB(ob) (explode(file_name(ob) + "#", "#")[0])
#define OB_NUM(ob) (explode(file_name(ob) + "#0", "#")[1])
#define MASTER MASTER_OB(this_object())
#define IS_CLONE (file_name(this_object()) != MASTER)
#define CLONE_COPY clone_object(MASTER)
#define CALL_BY_CLONE (MASTER == MASTER_OB(previous_object()))

#define CALL_BY(file) (MASTER_OB(previous_object()) == file)

#define LOAD_ERR(file)  catch(call_other(file, "??"))

#define FCHAR(str) extract(str, 0, 0)

#define LCALL this_object()->

#define MYLEV ((int)this_interactive()->query_wiz_level())
#define MYNAME ((string)this_interactive()->query_real_name())
#define MYDOMAIN ((string)this_interactive()->query_domain())

#define METNAME ((string)this_player()->query_name())
#define NONMETNAME (capitalize(this_player()->query_nonmet_name()))
#define ART_NONMETNAME (capitalize(LANG_ADDART(this_player()->query_nonmet_name())))

#define TART_NONMETNAME ("The " + (string)this_player()->query_nonmet_name())

#define VBFC(x) ("@@" + x + "@@")

#define VBFC_ME(x) "@@" + x + ":" + file_name(this_object()) + "@@"

/*
 * Here are some useful macros for using when figuring out player names.
 */
#ifdef MET_ACTIVE
#define QMET(func, ob) "@@" + func + ":" + file_name(ob) + "@@"
#else
#define QMET(func, ob) (call_other(ob, func, ob))
#endif
#define QSHORT(ob) QMET("vbfc_short", ob)

 /*
  * QNAME is uses 'value by function call'. It returns either the name
  * of the player or the race preceded by a or an. ob is the object
  * who we want check if we know.
  */
#define QNAME(ob) QMET("query_art_name", ob)

 /*
  * QCNAME is the same as QNAME except that it returns a capital A or An
  */
#define QCNAME(ob) QMET("query_Art_name", ob)
 /*
  * QTNAME is the same as QNAME except that it returns 'the'
  */
#define QTNAME(ob) QMET("query_the_name", ob)
 /*
  * QCTNAME is the same as QTNAME except that it returns a capital 'The'
  */
#define QCTNAME(ob) QMET("query_The_name", ob)
 /*
  * NAME always prints the name of the player with a capital letter.
  */
#define NAME this_player()->query_name()
/*
 * Can ob1 see ob2?
 */
#define CAN_SEE(ob1, ob2)	((int)ob2->check_seen(ob1))
/*
 * Can ob1 see anything in his/hers environment or is it too dark?
 */
#define CAN_SEE_IN_ROOM(ob)	(environment(ob) && \
				(environment(ob)->query_prop(OBJ_I_LIGHT) > \
				-(ob->query_prop(LIVE_I_SEE_DARK))))

#endif
